@@ -2,7 +2,7 @@
 const chalk = require('chalk');
 const {namespaceToName} = require('yeoman-environment');
 
-module.exports = (app, name) => {
+module.exports = async (app, name) => {
   const baseName = namespaceToName(name);
   app.insight.track('yoyo', 'run', baseName);
 
@@ -16,5 +16,5 @@ module.exports = (app, name) => {
   const generatorRunCount = app.conf.get('generatorRunCount');
   generatorRunCount[baseName] = generatorRunCount[baseName] + 1 || 1;
   app.conf.set('generatorRunCount', generatorRunCount);
-  app.env.run(name);
+  return app.env.run(name);
 };
